======
pymia
======

.. image:: https://readthedocs.org/projects/pymia/badge/?version=latest
	:target: http://pymia.readthedocs.io/en/latest/?badge=latest
	:alt: Documentation Status
	
pymia contains generic and often used code for medical image analysis.
It is developed and maintained by the Medical Image Analysis (MIA) group 
at the Institute for Surgical Technologies and Biomechanics (ISTB), University of Bern.
